@@ -994,7 +994,8 @@ typedef enum
 
 /* Snapshots
  * created:  2010-01-12
- * modified: 2010-04-23
+ * modified: 2012-09-04 (prefer Defaults-file over System-Defaults, don't save to Defaults any more)
+ *           2010-04-23
  */
 - (void)takeSnapshot:sender
 {   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
@@ -1033,39 +1034,103 @@ typedef enum
             file = [savePanel filename];
         else
             return;
-        if ( [file rangeOfString:name].length )
-            [defaults setObject:snapArray forKey:@"snapShotDocuments"];
+        if ( [file rangeOfString:name].length ) // if we save to Default.plist, we also save it to Defaults
+            [defaults removeObjectForKey:@"snapShotDocuments"]; // old -> delete
+            //[defaults setObject:snapArray forKey:@"snapShotDocuments"];
 
         [snapArray writeToFile:file atomically:YES];
     }
 }
 - (void)restoreSnapshot:sender
 {   NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
-    NSArray         *snapArray = [defaults objectForKey:@"snapShotDocuments"];
-    int             i;
+    NSString        *name = @"Default.plist";
+    NSArray         *snapArray = nil;   //[defaults objectForKey:@"snapShotDocuments"];
+    int             w, i;
+    BOOL            abortOp = NO;
 
     if ( [sender isKindOfClass:[NSMenuItem class]] )
     {   NSString    *path = vhfPathWithPathComponents(vhfUserLibrary(APPNAME), @".snapshots", nil);
-        NSString    *file, *name = @"Default.plist";
+        NSString    *file = vhfPathWithPathComponents(path, name, nil);
         NSOpenPanel *openPanel = [NSOpenPanel openPanel];
 
-        file = vhfPathWithPathComponents(path, name, nil);
         [openPanel setRequiredFileType:@"plist"];
         if ( [openPanel runModalForDirectory:path file:name] )
             file = [openPanel filename];
         else
             return;
-        if ( ! (snapArray = [NSArray arrayWithContentsOfFile:file]) )
-            snapArray = [defaults objectForKey:@"snapShotDocuments"];
+        if ( ! (snapArray = [NSArray arrayWithContentsOfFile:file]) )   // load from file
+            snapArray = [defaults objectForKey:@"snapShotDocuments"];   // no file -> load from System-Defaults
+    }
+    else    // load Defaults.plist or old @"snapShotDocuments" from System-Defaults
+    {   NSString    *path = vhfPathWithPathComponents(vhfUserLibrary(APPNAME), @".snapshots", nil);
+        NSString    *file = vhfPathWithPathComponents(path, name, nil);
+
+        if ( ! (snapArray = [NSArray arrayWithContentsOfFile:file]) )   // load from file
+            snapArray = [defaults objectForKey:@"snapShotDocuments"];   // no file -> load from System-Defaults
     }
 
+    // TODO: check for unsaved windows before starting restore snapshot from menu
+    for (w = [[self windows] count]-1; w >= 0; w--)
+    {	Document    *doc = [self documentInWindow:[[self windows] objectAtIndex:w]];
+
+        if (doc && [doc dirty])
+        {
+            switch (NSRunAlertPanel(CLOSEWINDOW_STRING, UNSAVEDDOCS_STRING, REVIEW_STRING, DONTSAVE_STRING, CANCEL_STRING))
+            {
+                case NSAlertDefaultReturn:      // review unsaved
+                    w = -1;
+                    break;
+                case NSAlertAlternateReturn:    // close anyway
+                    for (i = w; i >= 0; i--)
+                        [[self documentInWindow:[[self windows] objectAtIndex:i]] setDirty:NO];
+                    break;
+                default:                        // cancel
+                    return;
+            }
+        }
+    }
+    /* close documents which are not in snapArray */
+    for ( w = [[self windows] count]-1; w >= 0; w-- )
+    {	Document    *doc = [self documentInWindow:[[self windows] objectAtIndex:w]];
+
+        if (doc)
+        {   DocWindow   *window = [doc window];
+            NSString    *fileName = [doc filename];
+            BOOL        removeDoc = YES;
+
+            for (i=0; i<[snapArray count]; i++)
+            {   NSArray *array = [snapArray objectAtIndex:i];
+
+                if ( [array isKindOfClass:[NSArray class]] && [array count] >= 1 )
+                {   NSString    *path = [array objectAtIndex:0];
+
+                    if ( [path isEqual:fileName] )
+                    {   removeDoc = NO;
+                        break;  // keep document
+                    }
+                }
+            }   // end loop: snapArray
+            if ( removeDoc )
+            {
+                if ( ! [doc dirty] )
+                    [window performClose:self];
+                else
+                    abortOp = YES;
+            }
+        }
+    }
+    if ( abortOp )    // if window is not closed, then cancel
+        return;	// cancel restauration
+
+    /* open documents in snapArray */
     for (i=0; i<[snapArray count]; i++)
     {   NSArray *array = [snapArray objectAtIndex:i];
 
         if ( [array isKindOfClass:[NSString class]] )   // old format
             [self openFile:[snapArray objectAtIndex:i]];
         else if ([array count] >= 1)
-        {   NSString        *path = [array objectAtIndex:0];
+        {   NSString    *path = [array objectAtIndex:0];
+            Document    *doc;
 
 #           ifdef __APPLE__ // keep things working through transition to new Library-location
             NSFileManager   *fileManager = [NSFileManager defaultManager];
@@ -1083,30 +1148,31 @@ typedef enum
             }
 #           endif
             [self openFile:path];
+            doc = (document) ? document : [self currentDocument];   // current doc if doc was open already
 
-            if (document && [array count] >= 2) // point or rect
+            if (doc && [[doc filename] isEqual:path] && [array count] >= 2) // point or rect
             {    NSArray    *components = [[array objectAtIndex:1] componentsSeparatedByString:@" "];
 
                 if ( [components count] >= 4 )       // rectangle
                 {   NSRect  rect = rectFromPropertyList([array objectAtIndex:1]);
 
-                    [[document window] setFrame:rect display:NO];
+                    [[doc window] setFrame:rect display:NO];
 #ifdef __APPLE__
                     if ( [array count] >= 3 &&  // unfoldedSize
                         [[array objectAtIndex:2] respondsToSelector:@selector(floatValue)] )
                     {   float   h = [[array objectAtIndex:2] floatValue];
-                        [[document window] setUnfoldedHeight:h];
+                        [[doc window] setUnfoldedHeight:h];
                     }
 #endif
                 }
                 else                            // point only (v 3.9.1 only)
                 {   NSPoint p = pointFromPropertyList([array objectAtIndex:1]);
 
-                    [[document window] setFrameOrigin:p];
+                    [[doc window] setFrameOrigin:p];
                 }
             }
         }
-    }
+    }   // end loop: snapArray
 }
 
 /*
