@@ -619,24 +619,29 @@ static NSMutableArray *zoneList = nil;
 #endif
 
 - (void)scale:(float)x :(float)y withCenter:(NSPoint)center
+{
+    NSLog(@"[document scale:x :y ...] is deprecated, use [document scale:NSSize ...");
+    [self scale:NSMakeSize(x, y) withCenter:center];
+}
+- (void)scale:(NSSize)scaleSize withCenter:(NSPoint)center
 {   NSPoint	p = {0, 0};
     DocView	*view = [scrollView documentView];
     NSRect	oldFrame = [view frame], bRect;
 
     /* scale doc view and cache window */
-    [view scaleUnitSquareToSize:NSMakeSize(x, y)];
+    [view scaleUnitSquareToSize:scaleSize];
 
     [window disableFlushWindow];
 
     /* resize doc view and cache window (old size * scaleFactor) */
-    [view setFrameSize:NSMakeSize(NSWidth(oldFrame)*x, NSHeight(oldFrame)*y)];	// resize view
+    [view setFrameSize:NSMakeSize(NSWidth(oldFrame)*scaleSize.width, NSHeight(oldFrame)*scaleSize.height)];	// resize
 
     oldFrame = [window frame];
     oldFrame = [view convertRect:oldFrame fromView:nil];
     bRect = [view bounds];
     p = center;
-    if ((p.x -= oldFrame.size.width /2.0)<0.0) p.x = 0.0;
-    if ((p.y -= oldFrame.size.height/2.0)<0.0) p.y = 0.0;
+    if ((p.x -= oldFrame.size.width /2.0) < 0.0) p.x = 0.0;
+    if ((p.y -= oldFrame.size.height/2.0) < 0.0) p.y = 0.0;
     if (p.x > bRect.size.width  - oldFrame.size.width)  p.x = bRect.size.width  - oldFrame.size.width;
     if (p.y > bRect.size.height - oldFrame.size.height) p.y = bRect.size.height - oldFrame.size.height;
     [view scrollPoint:p];
@@ -857,7 +862,7 @@ static NSMutableArray *zoneList = nil;
  * ???kb NSString - This now returns an autorelease... I tried to fix up
  * all users of this, but it may kill something!
  */
-- (NSString *)filename
+- (NSString*)filename
 {   NSString	*returnString = @"";
 
     if (!directory && !name)
@@ -866,13 +871,11 @@ static NSMutableArray *zoneList = nil;
         returnString = [directory stringByAppendingPathComponent:name];
     return returnString;
 }
-
-- (NSString *)directory
+- (NSString*)directory
 {
     return directory;
 }
-
-- (NSString *)name
+- (NSString*)name
 {
     return name;
 }
