@@ -4,7 +4,8 @@
  * Author:   Ilonka Fleischmann
  *
  * created:  2000-12-21
- * modified: 2012-02-07 (-writeToFile: use writeToFile:...encoding:error:)
+ * modified: 2012-09-13 (-writeToFile: workaround: keep scaleFactor >= 1.0 not to clip graphics)
+ *           2012-02-07 (-writeToFile: use writeToFile:...encoding:error:)
  *
  * This file is part of the vhf Export Library.
  *
@@ -34,7 +35,7 @@
 
 #include <AppKit/AppKit.h>
 #include <VHFShared/vhfCommonFunctions.h>
-#include <VHFShared/VHFStringAdditions.h> // stringByReplacing -> eps export
+#include <VHFShared/VHFStringAdditions.h> // stringByReplacing -> eps export, -writeToFile:... 10.5 compatibility
 #include "App.h"
 #include "EPSExport.h"
 #include "Graphics.h"
@@ -360,6 +361,7 @@ epsState->noPoint = 1;
         NSRect		bRect;
         NSPoint		ll, ur;
         int         i, cnt;
+        VFloat      sf = [docView scaleFactor];
 
         // bRect = [docView bounds];
         ll.x = ll.y = MAXCOORD;
@@ -379,8 +381,12 @@ epsState->noPoint = 1;
             if ( ur.x < rect.origin.x+rect.size.width )  ur.x = rect.origin.x+rect.size.width;
             if ( ur.y < rect.origin.y+rect.size.height ) ur.y = rect.origin.y+rect.size.height;
         }
-        bRect.origin.x = ll.x;          bRect.origin.y = ll.y;
+        bRect.origin.x   = ll.x;        bRect.origin.y    = ll.y;
         bRect.size.width = ur.x - ll.x; bRect.size.height = ur.y - ll.y;
+        //bRect.size.width  *= (sf > 0.0) ? (sf) : (1.0);
+        //bRect.size.height *= (sf > 0.0) ? (sf) : (1.0);
+        bRect.size.width  *= (sf < 1.0) ? (1.0) : (sf); // workaround Apple: otherwise graphics gets clipped
+        bRect.size.height *= (sf < 1.0) ? (1.0) : (sf);
         psData = [docView dataWithEPSInsideRect:bRect];
         string = [[NSString alloc] initWithData:psData encoding:NSASCIIStringEncoding];
         //savedOk = [string writeToFile:filename atomically:YES];
