@@ -5,7 +5,8 @@
  * Author:   Georg Fleischmann
  *
  * created:  1996-05-01
- * modified: 2012-02-04 (-scanGroup: transform coordinates from OCS to WCS, if necessary)
+ * modified: 2012-09-13 (Diff(l, 0.0) < 0.0000001, else division with 0)
+ *           2012-02-04 (-scanGroup: transform coordinates from OCS to WCS, if necessary)
  *           2012-02-03 (InternalToDeviceRes(), DeviceResToInternal(): float -> double)
  *           2011-12-11 (-getGraphicFromData: TODO for SPLINEs added)
  *           2011-04-04 (-getGraphicFromData: 3DFACE TODO-log added)
@@ -1086,7 +1087,8 @@ static NSColor *getColorFromTable(NSString *str, NSArray *table)
 }
 
 /* Note: see page 323 of DXF book
- * modified: 2010-10-31 (dx, dy calced with double)
+ * modified: 2012-09-13 (Diff(l, 0.0) < 0.0000001, else division with 0)
+ *           2010-10-31 (dx, dy calced with double)
  *           2010-06-11 (360 - acos(cn))
  *           2010-04-03
  */
@@ -1097,6 +1099,12 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
 
     ang = 4.0 * RadToDeg(atan( a ));
     l = sqrt(SqrDistPoints(beg, end));  // length of arc from point to point
+    if ( Diff(l, 0.0) < 0.0000001 )
+    {
+        *ctr = beg;     // null length arc else division with 0
+        *angle = 0.0;
+        return;
+    }
     h = (a*l)/2.0;                      // height of arc
     mx = (begx+endx)/2.0; my = (begy+endy)/2.0; // mit point between start and end
     dx = mx - begx;                     // 
@@ -1729,7 +1737,7 @@ static V3Point transformOCS(V3Point pOCS, V3Point AZ)
                 if (![scanner scanFloat:&group.extY])
                     group.extY = 0.0;
                 if ( group.extX != 0.0 || group.extY != 0.0 )   // FIXME: extrusion direction
-                    NSLog(@"DXF-Import: extrusion direction not supported. File-Location = %d", [scanner scanLocation]);
+                    NSLog(@"DXF-Import: extrusion direction not supported. File-Location = %lu", [scanner scanLocation]);
                 break;
             case ID_EXT_Z:
                 if (![scanner scanFloat:&group.extZ])
